#ifndef ConnectionDialog_h
#define ConnectionDialog_h

// $Id: ConnectionDialog.h,v 1.25 2014/09/24 17:58:58 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseDialog.h"
#include "ConnectionAttributes.h"
#include "ConnectionModel.h"
#include "ConnectionParser.h"
#include "Counter.h"
#include "ListModel.h"

#include <QPushButton>
#include <QCloseEvent>

class ConnectionFrame;
class SimpleListView;

//! handles list of connection attributes
class ConnectionDialog: public BaseDialog, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    ConnectionDialog( QWidget* );

    //! destructor
    virtual ~ConnectionDialog( void )
    {}

    //! connection frame
    ConnectionFrame& frame( void ) const
    { return *frame_; }

    protected:

    //! close
    virtual void closeEvent( QCloseEvent* );

    //! load connections from parser
    void _load( void );

    protected Q_SLOTS:

    //! save settings
    void _select( void );

    //! save settings
    void _save( void );

    //! remove settings
    void _remove( void );

    //! connect
    void _connect( void );

    //! toggle save password
    void _toggleSavePasswords( bool state );

    //! cancel
    void _cancel( void );

    //! update buttons
    void _updateButtons( void );

    private:

    //! model
    ConnectionModel model_;

    //! list
    SimpleListView* list_;

    //! connection parser
    ConnectionParser parser_;

    //! connection frame
    ConnectionFrame* frame_;

    //!@name buttons
    //@{

    //! save
    QPushButton* saveButton_;

    //! remove
    QPushButton* removeButton_;

    //! connect
    QPushButton* connectButton_;

    //@}

};

#endif
