// $Id: ConnectionFrame.cpp,v 1.23 2014/09/26 08:06:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionFrame.h"
#include "ConnectionFrame.moc"

#include "ConnectionAttributes.h"
#include "AnimatedLineEditor.h"
#include "GridLayout.h"
#include "Debug.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QPushButton>
#include <QValidator>

//_________________________________________________
ConnectionFrame::ConnectionFrame( QWidget* parent, const bool& showPassword ):
    QWidget( parent ),
    Counter( "ConnectionFrame" )
{

    Debug::Throw( "ConnectionFrame::ConnectionFrame.\n" );
    GridLayout *layout = new GridLayout();
    layout->setMaxCount( 2 );
    layout->setMargin( 2 );
    layout->setSpacing( 5 );
    layout->setColumnAlignment( 0, Qt::AlignVCenter|Qt::AlignRight );
    setLayout( layout );

    QLabel* label;

    // host
    layout->addWidget( label = new QLabel( tr( "Host:" ), this ) );
    layout->addWidget( host_ = new AnimatedLineEditor( this ) );
    label->setBuddy( host_ );

    // port
    layout->addWidget( label = new QLabel( tr( "Port:" ), this ) );
    layout->addWidget( port_ = new AnimatedLineEditor( this ) );
    port_->setText( XmlOptions::get().raw( "DEFAULT_PORT" ) );
    label->setBuddy( port_ );
    QIntValidator *validator = new QIntValidator( this );
    port_->setValidator( validator );

    // user
    layout->addWidget( label = new QLabel( tr( "User:" ), this ) );
    layout->addWidget( user_ = new AnimatedLineEditor( this ) );
    label->setBuddy( user_ );

    if( showPassword )
    {

        layout->addWidget( label = new QLabel( tr( "Password:" ), this ) );
        layout->addWidget( password_ = new AnimatedLineEditor( this ) );
        password_->setEchoMode( QLineEdit::Password );
        label->setBuddy( password_ );

    } else password_ = 0;

    layout->setColumnStretch( 1, 1 );
    Debug::Throw( "ConnectionFrame::ConnectionFrame - done.\n" );

}

//_________________________________________________
void ConnectionFrame::load( const ConnectionAttributes& attributes )
{

    Debug::Throw( "ConnectionFrame::load.\n" );
    host_->setText( attributes.host() );
    port_->setText( QString::number( attributes.port() ) );
    user_->setText( attributes.user() );
    if( password_ ) password_->setText( attributes.password() );

}

//_________________________________________________
ConnectionAttributes ConnectionFrame::attributes( void ) const
{
    Debug::Throw( "ConnectionFrame::attributes.\n" );

    // store connection
    ConnectionAttributes attributes;
    attributes.setHost( host_->text() );
    attributes.setUser( user_->text() );
    if( password_ ) attributes.setPassword( password_->text() );

    unsigned int port( 0 );
    port = port_->text().toUInt();
    attributes.setPort( port );
    Debug::Throw( "ConnectionFrame::attributes - done.\n" );

    return attributes;

}
