// $Id: FileIconProvider.cpp,v 1.16 2014/09/19 13:47:32 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileIconProvider.h"

#include "CustomPixmap.h"
#include "FileInfo.h"
#include "IconNames.h"
#include "IconEngine.h"

//__________________________________________________________________
const QIcon& FileIconProvider::icon( const BaseFileInfo& fileInfo, int type )
{

    // try from base class
    const QIcon& icon( BaseFileIconProvider::icon( fileInfo, type ) );
    if( !icon.isNull() ) return icon;

    // get relevant file info type
    if( type & BaseFileInfo::Navigator ) type = BaseFileInfo::Navigator;
    else type &= BaseFileInfo::Document|BaseFileInfo::Folder|BaseFileInfo::Link|BaseFileInfo::Hidden|FileInfo::Clipped;

    // build key
    Key key( fileInfo.file().extension(), type );

    // check if already created
    IconCache::const_iterator iter( icons_.find( key ) );
    if( iter != icons_.end() ) return iter.value();

    // create
    QIcon out;
    if( type & BaseFileInfo::Navigator ) out = IconEngine::get( IconNames::Parent );
    else if( type & BaseFileInfo::Folder ) out = IconEngine::get( IconNames::Folder );
    else if( type & BaseFileInfo::Document )
    {

        // try get icon from mimetypes
        out = mimeTypeIconProvider_.icon( fileInfo.file().extension() );
        if( out.isNull() ) out = IconEngine::get( IconNames::Document );

    }

    out = IconEngine::copy( out );
    if( type & BaseFileInfo::Link ) out = _linked( out );
    if( type & BaseFileInfo::Hidden ) out = _hidden( out );
    if( type & FileInfo::Clipped ) out = _clipped( out );

    // insert in map and return
    return icons_.insert( key, out ).value();

}
