/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "NewFolderDialog.h"
#include "NewFolderDialog.moc"

#include "LineEditor.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QLayout>

//____________________________________________________________________________
NewFolderDialog::NewFolderDialog( QWidget* parent, const FileInfo& fileInfo ):
    CustomDialog( parent )
{

    Debug::Throw( "NewFolderDialog::NewFolderDialog.\n" );

    // option name
    setOptionName( "NEW_FOLDER_DIALOG" );

    // label
    const QString buffer = QString( tr( "Create new folder in:\n%1" ) ).arg( fileInfo.file() );
    QLabel* textLabel( new QLabel( buffer, this ) );
    mainLayout().addWidget( textLabel );

    // editor
    mainLayout().addWidget( editor_ = new LineEditor( this ) );
    textLabel->setBuddy( editor_ );

    // set text and selection
    editor().setText( tr( "New Folder" ) );
    editor().setFocus();
    editor().selectAll();

    connect( editor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons()) );

    _updateButtons();

}

//____________________________________________________________________________
void NewFolderDialog::_updateButtons( void )
{ okButton().setEnabled( !editor().text().trimmed().isEmpty() ); }
